=================================================
py_tools
=================================================

.. image:: https://readthedocs.org/projects/py_tools/badge/?version=latest
        :target: http://py_tools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status               

.. image:: https://img.shields.io/travis/DerThorsten/py_tools.svg
        :target: https://travis-ci.org/DerThorsten/py_tools

.. image:: https://travis-ci.org/DerThorsten/py_tools.svg?branch=master
    :target: https://travis-ci.org/DerThorsten/py_tools

.. image:: https://circleci.com/gh/DerThorsten/py_tools/tree/master.svg?style=svg
    :target: https://circleci.com/gh/DerThorsten/py_tools/tree/master

.. image:: https://dev.azure.com/derthorstenbeier/py_tools/_apis/build/status/DerThorsten.py_tools?branchName=master
    :target: https://dev.azure.com/derthorstenbeier/py_tools/_build/latest?definitionId=1&branchName=master








Features
--------

Current features include: 
  * conda ready
  * pytest unit test
  * continous integration

  * coverall code coverage
  * documentation with sphinx
  * documentation on readthedocs




